`#system#`你是一个专精于知识图谱实体融合的可靠助手。
`#user#`# 上下文信息

# 目标实体（Entity）信息
<实体>
{{entity_name}}
</实体>

<实体上下文信息>
{{entity_summary}}
</实体上下文信息>

<属性>
{{entity_attribute}}
</属性>

## 待融合实体
{{entities_to_merge}}

# 你的任务
请基于待融合实体提供的信息，为目标实体更新摘要以及属性值。

## 注意事项
1. **摘要生成**
   - 摘要必须仅基于**目标实体与待融合实体**。
   - 内容必须与目标实体直接相关，且不可超过**{{summary_target}}字**。
   - 不得引入任何外部知识或编造信息。
   - 使用bulletpoint列表的形式，每行简要记述一条事实。
   - 请以**中文**记录摘要，专有名词可以使用原语言但主体需要为中文。

2. **属性提取**
   - 根据提供的上下文，从上下文中提取当前实体（{{entity_name}}）的相关属性。
   - 若已提供的实体属性有过时或者错误的情况，则将其更新为正确值。
   - 不允许进行推测或虚构。
   - 属性提取结果必须符合JSON格式。

3. **目标实体更新**
   - 若目标实体的已有摘要和属性无需更新，留空即可。
   - 摘要和属性结果必须聚焦于指定的实体（{{entity_name}}）。
   - 排除与该实体无关的其他信息。{{extra_message}}